==> piwigo-2.7.4.zip: piwigo/plugins/AdminTools/language/nb_NO/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Combine JS&CSS'] = 'Kombiner JS&amp;CSS';
$lang['Debug languages'] = 'Feilsøkingspråk';
$lang['Debug template'] = 'Feilsøking tema';
$lang['Properties page'] = 'Egenskapersiden';
$lang['Quick edit'] = 'Rask endring';
$lang['Revert'] = 'Omgjøre';
$lang['Save'] = 'Lagre';
$lang['Save visit in history'] = 'Lagre besøkshistorie';
$lang['Saved'] = 'Lagret';
$lang['Show SQL queries'] = 'Vis SQL spørringer';
$lang['View as'] = 'Se alle';
$lang['Viewing as <b>%s</b>.'] = 'Se som <b>%s</b>.';
$lang['Closed icon position'] = 'Låst ikonposisjon';
$lang['Give access to quick edit to photo owners even if they are not admin'] = 'Gi tilgang til hurtigredigering av bildeeier, selv om de ikke er admin';
$lang['Open toolbar by default'] = 'Åpne verktøy automatisk';
$lang['left'] = 'venstre';
$lang['right'] = 'høyre';
?>

==> piwigo-16.1.0.zip: piwigo/plugins/AdminTools/language/nb_NO/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Combine JS&CSS'] = 'Kombiner JS&amp;CSS';
$lang['Debug languages'] = 'Feilsøkingspråk';
$lang['Debug template'] = 'Feilsøking tema';
$lang['Properties page'] = 'Egenskapssiden';
$lang['Quick edit'] = 'Hurtigredigering';
$lang['Revert'] = 'Omgjøre';
$lang['Save'] = 'Lagre';
$lang['Save visit in history'] = 'Lagre besøkshistorie';
$lang['Saved'] = 'Lagret';
$lang['Show SQL queries'] = 'Vis SQL spørringer';
$lang['View as'] = 'Se som';
$lang['Viewing as <b>%s</b>.'] = 'Se som <b>%s</b>.';
$lang['Closed icon position'] = 'Låst ikonposisjon';
$lang['Give access to quick edit to photo owners even if they are not admin'] = 'Gi tilgang til bildets eier for hurtigredigering, selv om de ikke er admin';
$lang['Open toolbar by default'] = 'Åpne verktøy automatisk';
$lang['left'] = 'venstre';
$lang['right'] = 'høyre';
